//
//  ContentView.swift
//  SFSymbolsDemo
//
//  Created by Gabriel Theodoropoulos
//  https://serialcoder.dev
//

import SwiftUI

struct ContentView: View {
    @State private var soundLevel: Double = 0.5
    @State private var isRotating = false
    @State private var replaceSymbol = false
    
    var body: some View {
        /*
         NOTE:
         Comment out or uncomment the following blocks of code
         to try out the various modifiers that modify SF Symbols.
         */
        
        // MARK: - 1. Resize with the .font modifier
        VStack(spacing: 40) {
            Image(systemName: "star.fill")
                .font(.body)
            
            Image(systemName: "star.fill")
                .font(.title)
            
            Image(systemName: "star.fill")
                .font(.largeTitle)
        }
        
        
        // MARK: - 2. The imageScale modifier
        /*
         HStack(spacing: 40) {
         VStack(spacing: 40) {
         Image(systemName: "star.fill")
         .imageScale(.small)
         
         Image(systemName: "star.fill")
         .imageScale(.medium)
         
         Image(systemName: "star.fill")
         .imageScale(.large)
         }
         .font(.body)
         
         
         VStack(spacing: 40) {
         Image(systemName: "star.fill")
         .imageScale(.small)
         
         Image(systemName: "star.fill")
         .imageScale(.medium)
         
         Image(systemName: "star.fill")
         .imageScale(.large)
         }
         .font(.largeTitle)
         }
         */
        
        
        // MARK: - 3. imageScale and resizable modifiers
        /*
         // These two modifiers do not work together
         Image(systemName: "star.fill")
         .resizable()
         .imageScale(.small)
         */
        
        
        // MARK: - 4. Resize with the .frame modifier
        /*
         HStack(spacing: 40) {
         // Resized but stretched symbol
         Image(systemName: "star")
         .resizable()
         .frame(width: 50, height: 30)
         
         // Resized and no stretched symbol - equal width and height
         Image(systemName: "star")
         .resizable()
         .frame(width: 50, height: 50)
         
         // Resized and no stretched symbol - maintain aspect ratio
         Image(systemName: "star")
         .resizable()
         .scaledToFit()
         .frame(width: 50, height: 30)
         }
         */
        
        
        // MARK: - 5. Styling with symbolRenderingMode
        /*
         VStack(spacing: 40) {
         Image(systemName: "heart.circle.fill")
         .symbolRenderingMode(.monochrome)
         .foregroundStyle(.purple)
         
         Image(systemName: "heart.circle.fill")
         .symbolRenderingMode(.hierarchical)
         .foregroundStyle(.red)
         
         Image(systemName: "heart.circle.fill")
         .symbolRenderingMode(.palette)
         .foregroundStyle(.red, .yellow)
         
         Image(systemName: "heart.circle.fill")
         .symbolRenderingMode(.multicolor)
         
         Image(systemName: "cloud.sun.rain.fill")
         .symbolRenderingMode(.palette)
         .foregroundStyle(.gray, .yellow, .blue)
         }
         .font(.largeTitle)
         */
        
        
        // MARK: - 6. Variable symbols
        /*
         VStack {
         Image(systemName: "speaker.wave.3", variableValue: soundLevel)
         .font(.largeTitle)
         
         Slider(value: $soundLevel, in: 0...1)
         .padding()
         }
         */
        
        
        // MARK: - 7. Symbol variants
        /*
         HStack(spacing: 30) {
         VStack {
         Image(systemName: "person.fill")
         
         Image(systemName: "person")
         .symbolVariant(.fill)
         }
         
         VStack {
         Image(systemName: "person.circle")
         
         Image(systemName: "person")
         .symbolVariant(.circle)
         }
         
         VStack {
         Image(systemName: "person.slash")
         
         Image(systemName: "person")
         .symbolVariant(.slash)
         }
         }
         .font(.largeTitle)
         */
        
        
        // MARK: - 8. Animate symbols
        /*
         VStack(spacing: 40) {
         Image(systemName: "heart")
         .symbolEffect(.bounce)
         
         Image(systemName: "info.circle")
         .symbolEffect(.breathe.plain)
         
         Image(systemName: "person.wave.2")
         .symbolEffect(.bounce.down.byLayer)
         
         Image(systemName: "wifi")
         .symbolEffect(.variableColor.hideInactiveLayers,
         options: .repeat(.periodic(delay: 0.5)))
         
         Image(systemName: "star")
         .symbolEffect(.rotate, value: isRotating)
         .onTapGesture {
         isRotating.toggle()
         }
         
         Image(systemName: !replaceSymbol ? "plus" : "xmark")
         .contentTransition(.symbolEffect(.replace.downUp))
         .onTapGesture {
         replaceSymbol.toggle()
         }
         
         Image(systemName: "bell")
         .symbolEffect(.wiggle, options: .repeat(.periodic))
         .symbolRenderingMode(.monochrome)
         .foregroundStyle(.indigo)
         }
         .font(.largeTitle)
         .symbolVariant(.fill)
         .symbolRenderingMode(.multicolor)
         */
    }
}

#Preview {
    ContentView()
}
